==> gitlab-18.0.1-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/doc/user/packages/_index.md <==
---
stage: Package
group: Package Registry
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments
title: Packages and Registries
---

{{< details >}}

- Tier: Free, Premium, Ultimate
- Offering: GitLab.com, GitLab Self-Managed, GitLab Dedicated

{{< /details >}}

The GitLab [package registry](package_registry/_index.md) acts as a private or public registry
for a variety of common package managers. You can publish and share
packages, which can be easily consumed as a dependency in downstream projects.

## Container registry

The GitLab [Container Registry](container_registry/_index.md) is a secure and private registry for container images. It's built on open source software and completely integrated within GitLab. Use GitLab CI/CD to create and publish images. Use the GitLab [API](../../api/container_registry.md) to manage the registry across groups and projects.

## Terraform Module Registry

The GitLab [Terraform Module Registry](terraform_module_registry/_index.md) is a secure and private registry for Terraform modules. You can use GitLab CI/CD to create and publish modules.

## Virtual Registry

The GitLab [virtual registry](virtual_registry/_index.md) provides advanced caching, proxying, and distribution features to improve package management from external registries in GitLab.

## Dependency Proxy

The [Dependency Proxy](dependency_proxy/_index.md) is a local proxy for frequently-used upstream images and packages.

==> gitlab-18.6.2-1-x86_64.pkg.tar.zst: usr/share/webapps/gitlab/doc/user/packages/_index.md <==
---
stage: Package
group: Package Registry
info: To determine the technical writer assigned to the Stage/Group associated with this page, see https://handbook.gitlab.com/handbook/product/ux/technical-writing/#assignments
title: Packages and Registries
description: Package management, container registry, artifact storage, and dependency management.
---

{{< details >}}

- Tier: Free, Premium, Ultimate
- Offering: GitLab.com, GitLab Self-Managed, GitLab Dedicated

{{< /details >}}

The GitLab [package registry](package_registry/_index.md) acts as a private or public registry
for a variety of common package managers. You can publish and share
packages, which can be easily consumed as a dependency in downstream projects.

## Container registry

The GitLab [Container Registry](container_registry/_index.md) is a secure and private registry for container images. It's built on open source software and completely integrated within GitLab. Use GitLab CI/CD to create and publish images. Use the GitLab [API](../../api/container_registry.md) to manage the registry across groups and projects.

## Terraform Module Registry

The GitLab [Terraform Module Registry](terraform_module_registry/_index.md) is a secure and private registry for Terraform modules. You can use GitLab CI/CD to create and publish modules.

## Virtual registry

The GitLab [virtual registry](virtual_registry/_index.md) provides advanced caching, proxying, and distribution features to improve package management from external registries in GitLab.

## Dependency Proxy

The [Dependency Proxy](dependency_proxy/_index.md) is a local proxy for frequently-used upstream images and packages.
